#!/usr/bin/perl -w
#
# Description:
# 	add backbone coordinates to PXML file (or replaces them if already present)
#
# parameters:
# 	1: pxml file
#	2: pdb model
# 	3: output file
# 
#

if (@ARGV != 3) {
	die "Usage: add_bbone2pxml.pl pxml_file pdb_model output_file\n";
}

$pxml_file = $ARGV[0];
$model_file = $ARGV[1];
$output_file = $ARGV[2];

# error check files are available
if (! -f $pxml_file)
{	die "can't find pxml file: $pxml_file\n"; 	}
if (! -f $model_file)
{	die "can't find model file: $model_file\n"; 	}

open(PXML, $pxml_file);
@pxml_text = <PXML>;
close(PXML);

open(COORDS, $model_file);
@model_text = <COORDS>;
close(COORDS);

for $i(0..$#model_text)       {
        $line = $model_text[$i];
        if(($line =~ /^ATOM/))   {
                $atom_type = substr($line,13,2);
                
                if(($atom_type eq 'N ') or ($atom_type eq 'CA') or ($atom_type eq 'C '))    {       
                        push(@coords_text,$line);    
                }                               
        }
}

# if coordinates are already present, set flag
# 	replace them
#
# if not present, just insert them at the end of the file ...

$coords_present = 0;

# scan pxml to find insertion point
$ptr = 0;
$insert_end = -1;

$insert_start = -1;
$end_prot_tag = -1;
while($ptr <= $#pxml_text)
{
	if($pxml_text[$ptr] =~ /<coords>/) {
		$insert_start = $ptr;		
	}
	
        if($pxml_text[$ptr] =~ /<\/coords>/) {
		$insert_end = $ptr;		
	}
        
	if($pxml_text[$ptr] =~ /<\/protein/) {                
		$end_prot_tag = $ptr;
	}

	$ptr++;
}

# adjust ptr for last over count
$ptr--;

if($insert_start > -1) {
	$coords_present = 1;
}

open(OUT,">$output_file");

# if they are already present, replace them
if($coords_present == 1) {

	for $i(0..$insert_start)
	{	print OUT $pxml_text[$i];	}
	
	# insert coords
	print OUT "\t<bbone>\n";
	print OUT "\t\t<model>\n";

	for $i(0..$#coords_text)	{	
		print OUT $coords_text[$i];		
	}

	print OUT "\t\t</model>\n";
	print OUT "\t</bbone>\n";	
	
	for $i($insert_end..$#pxml_text)	{
        	print OUT $pxml_text[$i];	
        }

}
# if they are not present, just insert at end
else{
	for $i(0..($end_prot_tag-1))
	{	print OUT $pxml_text[$i];	}
	
	# insert coords
	print OUT "<coords>\n";
	print OUT "\t<bbone>\n";
	print OUT "\t\t<model>\n";

	for $i(0..$#coords_text)	{	
		$temp = $coords_text[$i];
		chomp($temp);
		print OUT $temp."\n";		
	}

	print OUT "\t\t</model>\n";
	print OUT "\t</bbone>\n";
	print OUT "</coords>\n";
	
	for $i($end_prot_tag..$#pxml_text)
	{	print OUT $pxml_text[$i];	}
}

close(OUT);
