#!/usr/bin/perl -w
#
# File:		check_model.pl
# Author:	Arlo Randall
#
# Description:
#	Checks the model to make sure the correct number of backbone atoms 
#	are present
#
# Parameters:
# 	[0]  sequence_length
#	[1]  model_file

if ($#ARGV!=1) {
  print "usage: perl check_model.pl seq_len model_file\n";
  exit;
}

$len = $ARGV[0];
$model_file = $ARGV[1];

open(MODEL, $model_file);
@model_text = <MODEL>;
close(MODEL);

 	
$n_ct = 0;
$ca_ct = 0;
$c_ct = 0;
        	
for $i(0..$#model_text) { 
	$line = $model_text[$i];
       		
	if($line =~ /ATOM/)   {
	        $temp = substr($line,12,4);
	        $atom = &trim($temp);        		       
	        		      
	        if($atom eq 'N')  {
	        	$n_ct++;
	        }
       		if($atom eq 'CA')  {
		      	$ca_ct++;
       		}
       		if($atom eq 'C')  {
			$c_ct++;
      		}               	                        
       	}          	
}	

if($n_ct == $len and $ca_ct == $len and $c_ct == $len) {
	# properly formatted
	print "1";
}
elsif(($n_ct+$ca_ct+$c_ct) > 0) {
	# incomplete, but in pdb format
	print "0";
}
else {
	# not in pdb format
	print "-1";
}    

#*****************************************
# trim whitespace from edges of string
sub trim {
	my $temp_string = $_[0];
	$temp_string =~ s/^\s+//;
	$temp_string =~ s/\s+$//;
	return $temp_string;
}